<!-- CHUNK ID: chunk_0D65A508  CHUNK TYPE: paragraph START_LINE:1 -->
[**Advanced**](./introduction.md) > **Language Code** _(current)_

<!-- CHUNK ID: h_rule_5e62bbcd  CHUNK TYPE: h_rule START_LINE:3 -->
---

<!-- CHUNK ID: chunk_00D95362  CHUNK TYPE: header START_LINE:5 -->
#### Google

<!-- CHUNK ID: chunk_C036D2E5  CHUNK TYPE: paragraph START_LINE:7 -->
Source <https://developers.google.com/admin-sdk/directory/v1/languages?hl=zh-cn>, organized by GPT-4o.

<!-- CHUNK ID: chunk_89056507  CHUNK TYPE: longtable_head START_LINE:9 -->
| Label in Chinese | Label | `Language Code` |
| --- | --- | --- |
| 阿姆哈拉语 | Amharic | `am` |
<!-- CHUNK ID: chunk_434D3480  CHUNK TYPE: longtable_content START_LINE:12 -->
| 阿拉伯语 | Arabic | `ar` |
<!-- CHUNK ID: chunk_4E045D6E  CHUNK TYPE: longtable_content START_LINE:13 -->
| 巴斯克语 | Basque | `eu` |
<!-- CHUNK ID: chunk_8BDA075A  CHUNK TYPE: longtable_content START_LINE:14 -->
| 孟加拉语 | Bengali | `bn` |
<!-- CHUNK ID: chunk_2B8A2E4A  CHUNK TYPE: longtable_content START_LINE:15 -->
| 英语（英国） | English (UK) | `en-GB` |
<!-- CHUNK ID: chunk_10CEEC80  CHUNK TYPE: longtable_content START_LINE:16 -->
| 葡萄牙语（巴西） | Portuguese (Brazil) | `pt-BR` |
<!-- CHUNK ID: chunk_40F26E94  CHUNK TYPE: longtable_content START_LINE:17 -->
| 保加利亚语 | Bulgarian | `bg` |
<!-- CHUNK ID: chunk_BAC1D2DD  CHUNK TYPE: longtable_content START_LINE:18 -->
| 加泰罗尼亚语 | Catalan | `ca` |
<!-- CHUNK ID: chunk_D8283F5F  CHUNK TYPE: longtable_content START_LINE:19 -->
| 切罗基语 | Cherokee | `chr` |
<!-- CHUNK ID: chunk_6C504077  CHUNK TYPE: longtable_content START_LINE:20 -->
| 克罗地亚语 | Croatian | `hr` |
<!-- CHUNK ID: chunk_EF7519DD  CHUNK TYPE: longtable_content START_LINE:21 -->
| 捷克语 | Czech | `cs` |
<!-- CHUNK ID: chunk_52641096  CHUNK TYPE: longtable_content START_LINE:22 -->
| 丹麦语 | Danish | `da` |
<!-- CHUNK ID: chunk_22A8086F  CHUNK TYPE: longtable_content START_LINE:23 -->
| 荷兰语 | Dutch | `nl` |
<!-- CHUNK ID: chunk_534B2AA9  CHUNK TYPE: longtable_content START_LINE:24 -->
| 英语（美国） | English (US) | `en` |
<!-- CHUNK ID: chunk_5B49CFFF  CHUNK TYPE: longtable_content START_LINE:25 -->
| 爱沙尼亚语 | Estonian | `et` |
<!-- CHUNK ID: chunk_F3BE0662  CHUNK TYPE: longtable_content START_LINE:26 -->
| 菲律宾语 | Filipino | `fil` |
<!-- CHUNK ID: chunk_AB091AA3  CHUNK TYPE: longtable_content START_LINE:27 -->
| 芬兰语 | Finnish | `fi` |
<!-- CHUNK ID: chunk_E9126CEE  CHUNK TYPE: longtable_content START_LINE:28 -->
| 法语 | French | `fr` |
<!-- CHUNK ID: chunk_6A475C12  CHUNK TYPE: longtable_content START_LINE:29 -->
| 德语 | German | `de` |
<!-- CHUNK ID: chunk_63D84713  CHUNK TYPE: longtable_content START_LINE:30 -->
| 希腊语 | Greek | `el` |
<!-- CHUNK ID: chunk_A6DD638F  CHUNK TYPE: longtable_content START_LINE:31 -->
| 古吉拉特语 | Gujarati | `gu` |
<!-- CHUNK ID: chunk_B85F863E  CHUNK TYPE: longtable_content START_LINE:32 -->
| 希伯来语 | Hebrew | `iw` |
<!-- CHUNK ID: chunk_108CDAD2  CHUNK TYPE: longtable_content START_LINE:33 -->
| 印地语 | Hindi | `hi` |
<!-- CHUNK ID: chunk_371C85CF  CHUNK TYPE: longtable_content START_LINE:34 -->
| 匈牙利语 | Hungarian | `hu` |
<!-- CHUNK ID: chunk_DFA87215  CHUNK TYPE: longtable_content START_LINE:35 -->
| 冰岛语 | Icelandic | `is` |
<!-- CHUNK ID: chunk_77057FC2  CHUNK TYPE: longtable_content START_LINE:36 -->
| 印度尼西亚语 | Indonesian | `id` |
<!-- CHUNK ID: chunk_FF3C4126  CHUNK TYPE: longtable_content START_LINE:37 -->
| 意大利语 | Italian | `it` |
<!-- CHUNK ID: chunk_652E29EB  CHUNK TYPE: longtable_content START_LINE:38 -->
| 日语 | Japanese | `ja` |
<!-- CHUNK ID: chunk_93927FAF  CHUNK TYPE: longtable_content START_LINE:39 -->
| 卡纳达语 | Kannada | `kn` |
<!-- CHUNK ID: chunk_56BC5C4A  CHUNK TYPE: longtable_content START_LINE:40 -->
| 韩语 | Korean | `ko` |
<!-- CHUNK ID: chunk_F96E1E17  CHUNK TYPE: longtable_content START_LINE:41 -->
| 拉脱维亚语 | Latvian | `lv` |
<!-- CHUNK ID: chunk_55EC6BB8  CHUNK TYPE: longtable_content START_LINE:42 -->
| 立陶宛语 | Lithuanian | `lt` |
<!-- CHUNK ID: chunk_D4EE46C1  CHUNK TYPE: longtable_content START_LINE:43 -->
| 马来语 | Malay | `ms` |
<!-- CHUNK ID: chunk_81884171  CHUNK TYPE: longtable_content START_LINE:44 -->
| 马拉雅拉姆语 | Malayalam | `ml` |
<!-- CHUNK ID: chunk_2560880A  CHUNK TYPE: longtable_content START_LINE:45 -->
| 马拉地语 | Marathi | `mr` |
<!-- CHUNK ID: chunk_FA300B7A  CHUNK TYPE: longtable_content START_LINE:46 -->
| 挪威语 | Norwegian | `no` |
<!-- CHUNK ID: chunk_7EBAF4DE  CHUNK TYPE: longtable_content START_LINE:47 -->
| 波兰语 | Polish | `pl` |
<!-- CHUNK ID: chunk_07BEC358  CHUNK TYPE: longtable_content START_LINE:48 -->
| 葡萄牙语（葡萄牙） | Portuguese (Portugal) | `pt-PT` |
<!-- CHUNK ID: chunk_0A7A2233  CHUNK TYPE: longtable_content START_LINE:49 -->
| 罗马尼亚语 | Romanian | `ro` |
<!-- CHUNK ID: chunk_AD2D309D  CHUNK TYPE: longtable_content START_LINE:50 -->
| 俄语 | Russian | `ru` |
<!-- CHUNK ID: chunk_9BA57E97  CHUNK TYPE: longtable_content START_LINE:51 -->
| 塞尔维亚语 | Serbian | `sr` |
<!-- CHUNK ID: chunk_9240CC91  CHUNK TYPE: longtable_content START_LINE:52 -->
| 中文（中国） | Chinese (PRC) | `zh-CN` |
<!-- CHUNK ID: chunk_A2F7B475  CHUNK TYPE: longtable_content START_LINE:53 -->
| 斯洛伐克语 | Slovak | `sk` |
<!-- CHUNK ID: chunk_4188ADDD  CHUNK TYPE: longtable_content START_LINE:54 -->
| 斯洛文尼亚语 | Slovenian | `sl` |
<!-- CHUNK ID: chunk_E4F70BC1  CHUNK TYPE: longtable_content START_LINE:55 -->
| 西班牙语 | Spanish | `es` |
<!-- CHUNK ID: chunk_08CB79D0  CHUNK TYPE: longtable_content START_LINE:56 -->
| 斯瓦希里语 | Swahili | `sw` |
<!-- CHUNK ID: chunk_5DCBD4C6  CHUNK TYPE: longtable_content START_LINE:57 -->
| 瑞典语 | Swedish | `sv` |
<!-- CHUNK ID: chunk_A604BFF4  CHUNK TYPE: longtable_content START_LINE:58 -->
| 泰米尔语 | Tamil | `ta` |
<!-- CHUNK ID: chunk_7E308345  CHUNK TYPE: longtable_content START_LINE:59 -->
| 泰卢固语 | Telugu | `te` |
<!-- CHUNK ID: chunk_B766F3D4  CHUNK TYPE: longtable_content START_LINE:60 -->
| 泰语 | Thai | `th` |
<!-- CHUNK ID: chunk_C1B06A67  CHUNK TYPE: longtable_content START_LINE:61 -->
| 中文（台湾） | Chinese (Taiwan) | `zh-TW` |
<!-- CHUNK ID: chunk_4F10E5FB  CHUNK TYPE: longtable_content START_LINE:62 -->
| 土耳其语 | Turkish | `tr` |
<!-- CHUNK ID: chunk_1B069A9E  CHUNK TYPE: longtable_content START_LINE:63 -->
| 乌尔都语 | Urdu | `ur` |
<!-- CHUNK ID: chunk_906AD05C  CHUNK TYPE: longtable_content START_LINE:64 -->
| 乌克兰语 | Ukrainian | `uk` |
<!-- CHUNK ID: chunk_275139A2  CHUNK TYPE: longtable_content START_LINE:65 -->
| 越南语 | Vietnamese | `vi` |
<!-- CHUNK ID: chunk_CADB0DBE  CHUNK TYPE: longtable_content START_LINE:66 -->
| 威尔士语 | Welsh | `cy` |


<!-- CHUNK ID: chunk_CD5EA97F  CHUNK TYPE: header START_LINE:69 -->
#### DeepL
<!-- CHUNK ID: chunk_CD419A2D  CHUNK TYPE: paragraph START_LINE:70 -->
Source <https://developers.deepl.com/docs/resources/supported-languages>, organized by GPT-4o.

<!-- CHUNK ID: chunk_73C925CB  CHUNK TYPE: longtable_head START_LINE:72 -->
| Label in Chinese | Label | `Language Code`| Supports |
| --- | --- | --- | --- |
| 阿拉伯语 | Arabic | `AR` | `source`, `target` |
<!-- CHUNK ID: chunk_449EF659  CHUNK TYPE: longtable_content START_LINE:75 -->
| 保加利亚语 | Bulgarian | `BG` | `source`, `target` |
<!-- CHUNK ID: chunk_F1AC6529  CHUNK TYPE: longtable_content START_LINE:76 -->
| 捷克语 | Czech | `CS` | `source`, `target` |
<!-- CHUNK ID: chunk_499838A9  CHUNK TYPE: longtable_content START_LINE:77 -->
| 丹麦语 | Danish | `DA` | `source`, `target` |
<!-- CHUNK ID: chunk_6E7A86D5  CHUNK TYPE: longtable_content START_LINE:78 -->
| 德语 | German | `DE` | `source`, `target` |
<!-- CHUNK ID: chunk_11DB586F  CHUNK TYPE: longtable_content START_LINE:79 -->
| 希腊语 | Greek | `EL` | `source`, `target` |
<!-- CHUNK ID: chunk_B38960C2  CHUNK TYPE: longtable_content START_LINE:80 -->
| 英语 | English | `EN` | `source`, `target` |
<!-- CHUNK ID: chunk_04ACBE3E  CHUNK TYPE: longtable_content START_LINE:81 -->
| 英语（英国） | English (British) | `EN-GB` | `target` |
<!-- CHUNK ID: chunk_16A4376D  CHUNK TYPE: longtable_content START_LINE:82 -->
| 英语（美国） | English (American) | `EN-US` | `target` |
<!-- CHUNK ID: chunk_B4390A6E  CHUNK TYPE: longtable_content START_LINE:83 -->
| 西班牙语 | Spanish | `ES` | `source`, `target` |
<!-- CHUNK ID: chunk_BB651F90  CHUNK TYPE: longtable_content START_LINE:84 -->
| 爱沙尼亚语 | Estonian | `ET` | `source`, `target` |
<!-- CHUNK ID: chunk_8C2548A1  CHUNK TYPE: longtable_content START_LINE:85 -->
| 芬兰语 | Finnish | `FI` | `source`, `target` |
<!-- CHUNK ID: chunk_9D18F62B  CHUNK TYPE: longtable_content START_LINE:86 -->
| 法语 | French | `FR` | `source`, `target` |
<!-- CHUNK ID: chunk_9E56C34E  CHUNK TYPE: longtable_content START_LINE:87 -->
| 匈牙利语 | Hungarian | `HU` | `source`, `target` |
<!-- CHUNK ID: chunk_B22D2080  CHUNK TYPE: longtable_content START_LINE:88 -->
| 印度尼西亚语 | Indonesian | `ID` | `source`, `target` |
<!-- CHUNK ID: chunk_4033F9B6  CHUNK TYPE: longtable_content START_LINE:89 -->
| 意大利语 | Italian | `IT` | `source`, `target` |
<!-- CHUNK ID: chunk_69D4C3F5  CHUNK TYPE: longtable_content START_LINE:90 -->
| 日语 | Japanese | `JA` | `source`, `target` |
<!-- CHUNK ID: chunk_D3B9AFD6  CHUNK TYPE: longtable_content START_LINE:91 -->
| 韩语 | Korean | `KO` | `source`, `target` |
<!-- CHUNK ID: chunk_82B11E30  CHUNK TYPE: longtable_content START_LINE:92 -->
| 立陶宛语 | Lithuanian | `LT` | `source`, `target` |
<!-- CHUNK ID: chunk_8EE65B58  CHUNK TYPE: longtable_content START_LINE:93 -->
| 拉脱维亚语 | Latvian | `LV` | `source`, `target` |
<!-- CHUNK ID: chunk_BE638C29  CHUNK TYPE: longtable_content START_LINE:94 -->
| 挪威博克马尔语 | Norwegian Bokmål | `NB` | `source`, `target` |
<!-- CHUNK ID: chunk_6A6B98E7  CHUNK TYPE: longtable_content START_LINE:95 -->
| 荷兰语 | Dutch | `NL` | `source`, `target` |
<!-- CHUNK ID: chunk_830AFF98  CHUNK TYPE: longtable_content START_LINE:96 -->
| 波兰语 | Polish | `PL` | `source`, `target` |
<!-- CHUNK ID: chunk_49AAA50E  CHUNK TYPE: longtable_content START_LINE:97 -->
| 葡萄牙语 | Portuguese | `PT` | `source`, `target` |
<!-- CHUNK ID: chunk_FF12E792  CHUNK TYPE: longtable_content START_LINE:98 -->
| 葡萄牙语（巴西） | Portuguese (Brazilian) | `PT-BR` | `target` |
<!-- CHUNK ID: chunk_7E188EC0  CHUNK TYPE: longtable_content START_LINE:99 -->
| 葡萄牙语（欧洲） | Portuguese (European) | `PT-PT` | `target` |
<!-- CHUNK ID: chunk_557425BD  CHUNK TYPE: longtable_content START_LINE:100 -->
| 罗马尼亚语 | Romanian | `RO` | `source`, `target` |
<!-- CHUNK ID: chunk_0FBF4463  CHUNK TYPE: longtable_content START_LINE:101 -->
| 俄语 | Russian | `RU` | `source`, `target` |
<!-- CHUNK ID: chunk_11FAA384  CHUNK TYPE: longtable_content START_LINE:102 -->
| 斯洛伐克语 | Slovak | `SK` | `source`, `target` |
<!-- CHUNK ID: chunk_117E9013  CHUNK TYPE: longtable_content START_LINE:103 -->
| 斯洛文尼亚语 | Slovenian | `SL` | `source`, `target` |
<!-- CHUNK ID: chunk_EF0CF035  CHUNK TYPE: longtable_content START_LINE:104 -->
| 瑞典语 | Swedish | `SV` | `source`, `target` |
<!-- CHUNK ID: chunk_41772AFF  CHUNK TYPE: longtable_content START_LINE:105 -->
| 土耳其语 | Turkish | `TR` | `source`, `target` |
<!-- CHUNK ID: chunk_95BAEB3E  CHUNK TYPE: longtable_content START_LINE:106 -->
| 乌克兰语 | Ukrainian | `UK` | `source`, `target` |
<!-- CHUNK ID: chunk_DED8F856  CHUNK TYPE: longtable_content START_LINE:107 -->
| 中文 | Chinese | `ZH` | `source`, `target` |
<!-- CHUNK ID: chunk_8EC779FC  CHUNK TYPE: longtable_content START_LINE:108 -->
| 中文（简体） | Chinese (Simplified) | `ZH-HANS` | `target` |
<!-- CHUNK ID: chunk_357772FB  CHUNK TYPE: longtable_content START_LINE:109 -->
| 中文（繁体） | Chinese (Traditional) | `ZH-HANT` | `target` |
